``zope.securitypolicy``
=======================

.. image:: https://travis-ci.org/zopefoundation/zope.securitypolicy.png?branch=master
        :target: https://travis-ci.org/zopefoundation/zope.securitypolicy

This package provides an useful security policy for Zope3. It's the
default security policy used in "zope3 the application" and many other
zope-based projects.
